@@ -1,4 +1,4 @@
-package TeX::Hyphen::Pattern 0.102;    # -*- cperl; cperl-indent-level: 4 -*-
+package TeX::Hyphen::Pattern 0.103;    # -*- cperl; cperl-indent-level: 4 -*-
 use Moose;
 use 5.014000;
 use utf8;
@@ -34,15 +34,15 @@ Readonly::Scalar my $ERR_CANT_WRITE => q{Can't write to file '%s', stopped %s};
 
 Readonly::Hash my %FALLBACK => (
     'De_DE' => q{De_1996_ec},
-    'Af-za' => q{Af_ec},
-    'Da-DK' => q{Da_ec},
-    'Et-ee' => q{Et_ec},
-    'Fr-fr' => q{Fr_ec},
-    'It-it' => q{It},
-    'Lt-lt' => q{Lt},
-    'Nl-nl' => q{Nl},
-    'Pl-pl' => q{Pl},
-    'Pt-br' => q{Pt},
+    'Af_za' => q{Af_ec},
+    'Da_DK' => q{Da_ec},
+    'Et_ee' => q{Et_ec},
+    'Fr_fr' => q{Fr_ec},
+    'It_it' => q{It},
+    'Lt_lt' => q{Lt},
+    'Nl_nl' => q{Nl},
+    'Pl_pl' => q{Pl},
+    'Pt_br' => q{Pt},
     'Sh'    => q{Sh_latn},
     'Sl'    => q{Sl},
 );
@@ -149,6 +149,7 @@ sub _replug {
     my ($self) = @_;
     my $module = ucfirst $self->label;
     $module =~ s/$DASH/$UNDERSCORE/xmgis;
+    my $label = $module;
     $module = $PLUGGABLE . $module;
 
     # Find a match with decreasing strictness:
@@ -164,9 +165,9 @@ sub _replug {
     }
     if ( !@available ) {
         $log->warn( sprintf $LOG{'NO_MATCH_PARTIAL'}, $module );
-        if ( exists $FALLBACK{$module} ) {
-            my $fallback = $FALLBACK{$module};
-            @available = grep { /^$fallback/xmgis } $self->available();
+        if ( exists $FALLBACK{$label} ) {
+            $module = $PLUGGABLE . $FALLBACK{$label};
+            @available = grep { /^$module/xmgis } $self->available();
         }
     }
     @available = sort @available;
@@ -202,7 +203,7 @@ patterns for use with TeX::Hyphen.
 
 =head1 VERSION
 
-This is version 0.102. To prevent plugging in of incompatible modules the
+This is version 0.103. To prevent plugging in of incompatible modules the
 version of the pluggable modules must be the same as this module.
 
 =head1 SYNOPSIS
@@ -302,7 +303,7 @@ L<TeX::Hyphen|TeX::Hyphen>.  Versions up to and including 0.140 don't support
 C<utf8>, so patterns using C<utf8> that are included in this package have a
 version number 0.00 to ignore them. Should you patch
 L<TeX::Hyphen|TeX::Hyphen> yourself by inserting a C<binmode FILE, ":utf8";>
-you can change those version numbers to 0.102 to include them.
+you can change those version numbers to 0.103 to include them.
 
 =back
 
